@@ -7,6 +7,7 @@ from io import BytesIO
 from urllib.request import Request, urlopen  # Python 3
 import pyimgbox
 import aiohttp
+from urllib.parse import urlparse
 
 def get(record):
 
@@ -41,10 +42,16 @@ def get_image_from_path(image_object, filepath):
 
 
 def get_image_from_url(url):
-    
+
+
+    domain = urlparse(url).netloc
+    domain = domain.replace('www.', '')
+    referer = 'https//' + str(domain)
+
+
     # Load image
     headers = {'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/50.0.2661.102 Safari/537.36',
-    'referer': 'https://youramateurporn.com/'
+    'referer': referer
     }
 
     try:
@@ -57,10 +64,15 @@ def get_image_from_url(url):
         return None
 
 async def get_image_from_url_async(url):
+
+    domain = urlparse(url).netloc
+    domain = domain.replace('www.', '')
+    referer = 'https//' + str(domain)
+
     
     # Load image
     headers = {'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/50.0.2661.102 Safari/537.36',
-    'referer': 'https://youramateurporn.com/'
+    'referer': referer
     }
 
     timeout = aiohttp.ClientTimeout(total=10)
