@@ -1,4 +1,6 @@
 from kraken_image_processing import download_models
+import os
+import asyncio
 
 download_models.download_models()
 
@@ -9,7 +11,6 @@ from kraken_image_processing.extractors import kraken_image_face
 from kraken_image_processing.extractors import kraken_image_text
 
 from kraken_image_processing import download_models
-import os
 
 
 from io import BytesIO
@@ -49,6 +50,8 @@ def process(record, image_byte = None, filepath = None,):
 
         record['temp:pil_img'] = pil_img
 
+    if not image_byte and not filepath:
+        record = asyncio.run(load_async(record))
 
     # Load image
     pil_img = record.get('temp:pil_img', None)
@@ -73,13 +76,13 @@ def process(record, image_byte = None, filepath = None,):
     records += kraken_image_text.get(record)
 
     # process objects from image
-    print('Get text')
+    print('Get objects')
     #records += kraken_image_objects.get(record)
 
     # Save original image to share
+    print('Post to image share')
     records += post_to_image_share.post(record)
-
-
+    
     return records
 
 
